@@ -39,7 +39,7 @@ from .attributes.simples import (
     TimeAttribute,
     UUIDAttribute,
 )
-from .batches.checks import print_health
+from .health import check_health, print_health
 from .constants import ASC, DESC
 from .databases import Database, connection
 from .exceptions import (
@@ -54,6 +54,7 @@ from .exceptions import (
     QuerySetUnpackException,
     EmptyQuerySetUnpackException,
     PrimaryKeyException,
+    UniqueIndexException,
 )
 from .models import (
     AttributeModel,
