@@ -58,6 +58,7 @@ class StringAttribute(TypedAttribute):
     """Stores a :class:`str` object."""
 
     type = str
+    nullok = False
 
 
 class UUIDAttribute(BaseAttribute):
@@ -70,7 +71,7 @@ class UUIDAttribute(BaseAttribute):
         if isinstance(value, Integral):
             return uuid.UUID(int=value).int
 
-        if isinstance(value, (bytes, str, "".__class__)):
+        if isinstance(value, (bytes, str)):
             return uuid.UUID(value).int
 
         return value.int
